@@ -17,8 +17,6 @@
 
 #include <QUrl>
 
-class KJob;
-
 namespace KManageSieve
 {
 class Session;
@@ -91,18 +89,18 @@ public:
     /**
      * Returns the sieve capabilities of the IMAP server.
      */
-    QStringList sieveCapabilities() const;
+    Q_REQUIRED_RESULT QStringList sieveCapabilities() const;
 
     /**
      * Returns whether the requested sieve script exists on
      * the IMAP server.
      */
-    bool fileExists() const;
+    Q_REQUIRED_RESULT bool fileExists() const;
 
     /**
      * A human-readable error message.
      */
-    QString errorString() const;
+    Q_REQUIRED_RESULT QString errorString() const;
 
 Q_SIGNALS:
     /**
@@ -148,7 +146,7 @@ Q_SIGNALS:
 
 private:
     Q_DISABLE_COPY(SieveJob)
-    void setErrorMessage(const QString &str);
+    KMANAGESIEVE_NO_EXPORT void setErrorMessage(const QString &str);
 
     //@cond PRIVATE
     explicit SieveJob(QObject *parent = nullptr);
