@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,12 +8,13 @@
 #include "editor/sieveeditorutil.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
+#include "libksieve_debug.h"
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QXmlStreamReader>
-#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 SieveActionBreak::SieveActionBreak(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -23,15 +24,16 @@ SieveActionBreak::SieveActionBreak(SieveEditorGraphicalModeWidget *sieveGraphica
 
 QWidget *SieveActionBreak::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    QLabel *lab = new QLabel(i18n("Name (optional):"));
+    auto lab = new QLabel(i18n("Name (optional):"));
     lay->addWidget(lab);
 
-    auto *subject = new QLineEdit;
+    auto subject = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(subject, w);
     subject->setObjectName(QStringLiteral("name"));
     connect(subject, &QLineEdit::textChanged, this, &SieveActionBreak::valueChanged);
     lay->addWidget(subject);
@@ -41,11 +43,15 @@ QWidget *SieveActionBreak::createParamWidget(QWidget *parent) const
 void SieveActionBreak::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("name")) {
-                auto *name = w->findChild<QLineEdit *>(QStringLiteral("name"));
+                auto name = w->findChild<QLineEdit *>(QStringLiteral("name"));
                 name->setText(AutoCreateScriptUtil::strValue(element));
             } else {
                 unknownTagValue(tagValue, error);
@@ -53,13 +59,13 @@ void SieveActionBreak::setParamWidgetValue(QXmlStreamReader &element, QWidget *w
             }
         } else if (tagName == QLatin1String("str")) {
             element.skipCurrentElement();
-            //Nothing
+            // Nothing
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << "SieveActionBreak::setParamWidgetValue unknown tag " << tagName;
@@ -87,7 +93,7 @@ QString SieveActionBreak::help() const
     return i18n("The break command terminates the closest enclosing loop.");
 }
 
-QStringList SieveActionBreak::needRequires(QWidget */*parent*/) const
+QStringList SieveActionBreak::needRequires(QWidget * /*parent*/) const
 {
     return QStringList() << QStringLiteral("foreverypart");
 }
