@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SELECTCOMPARATORCOMBOBOX_H
-#define SELECTCOMPARATORCOMBOBOX_H
+#pragma once
 
 #include <QComboBox>
 namespace KSieveUi
@@ -30,4 +29,3 @@ private:
     void initialize(const QStringList &sieveCapabilities);
 };
 }
-#endif // SELECTCOMPARATORCOMBOBOX_H
