@@ -15,6 +15,7 @@
 #include <KLocalizedString>
 #include <QIcon>
 #include <QPushButton>
+#include <QScrollArea>
 
 #include "libksieve_debug.h"
 #include <QCheckBox>
@@ -199,7 +200,14 @@ SieveIncludeWidget::SieveIncludeWidget(QWidget *parent)
 
     mIncludeLister = new SieveIncludeWidgetLister(this);
     connect(mIncludeLister, &SieveIncludeWidgetLister::valueChanged, this, &SieveIncludeWidget::valueChanged);
-    lay->addWidget(mIncludeLister, 0, Qt::AlignTop);
+
+    auto scrollArea = new QScrollArea(this);
+    scrollArea->setAutoFillBackground(false);
+    scrollArea->setWidget(mIncludeLister);
+    scrollArea->setWidgetResizable(true);
+    scrollArea->setAlignment(Qt::AlignTop);
+    lay->addWidget(scrollArea);
+
     setPageType(KSieveUi::SieveScriptBlockWidget::Include);
 }
 
@@ -319,6 +327,7 @@ void SieveIncludeWidgetLister::clearWidget(QWidget *aWidget)
     if (aWidget) {
         auto widget = static_cast<SieveIncludeActionWidget *>(aWidget);
         widget->clear();
+        updateAddRemoveButton();
     }
     Q_EMIT valueChanged();
 }
