@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ SieveEditorHelpHtmlWidgetTest::SieveEditorHelpHtmlWidgetTest(QObject *parent)
 {
 }
 
-SieveEditorHelpHtmlWidgetTest::~SieveEditorHelpHtmlWidgetTest()
-{
-}
+SieveEditorHelpHtmlWidgetTest::~SieveEditorHelpHtmlWidgetTest() = default;
 
 void SieveEditorHelpHtmlWidgetTest::shouldHaveDefaultValue()
 {
