@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -122,7 +122,7 @@ void XMLPrintingScriptBuilderTest::shouldCreateXml()
 
     const QString originalFile = QLatin1String(XMLPRINTINGSCRIPTBUILDER_DATA_DIR) + QLatin1Char('/') + input + QStringLiteral(".siv");
     const QString refFile = QLatin1String(XMLPRINTINGSCRIPTBUILDER_DATA_DIR) + QLatin1Char('/') + input + QStringLiteral("-ref.siv");
-    const QString generatedFile = QLatin1String(XMLPRINTINGSCRIPTBUILDER_DATA_DIR) + QLatin1Char('/') + input + QStringLiteral("-generated.siv");
+    const QString generatedFile = QLatin1String(XMLPRINTINGSCRIPTBUILDER_GENERATED_DATA_DIR) + QLatin1Char('/') + input + QStringLiteral("-generated.siv");
     const QByteArray script = readSieveFile(originalFile);
     KSieve::Parser parser(script.begin(), script.begin() + script.length());
     KSieveUi::XMLPrintingScriptBuilder builder;
