@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,18 +14,20 @@
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <QShortcut>
 #include <QVBoxLayout>
+#include <QWindow>
 
 #include <editor/sievetexteditwidget.h>
-#include <kpimtextedit/kpimtextedit-texttospeech.h>
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-#include <KPIMTextEdit/TextToSpeechWidget>
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeechContainerWidget>
 #endif
+
 using namespace KSieveUi;
 namespace
 {
@@ -64,8 +66,8 @@ SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTe
     hbox->addWidget(mTemplateNameEdit);
 
     vbox->addLayout(hbox);
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-    auto textToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    auto textToSpeechWidget = new TextEditTextToSpeech::TextToSpeechContainerWidget(this);
     vbox->addWidget(textToSpeechWidget);
 #endif
 
@@ -73,9 +75,10 @@ SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTe
     mTextEditWidget->textEdit()->setShowHelpMenu(false);
     mTextEditWidget->setReadOnly(defaultTemplate);
     vbox->addWidget(mTextEditWidget);
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-    connect(mTextEditWidget->textEdit(), &SieveTextEdit::say, textToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    connect(mTextEditWidget->textEdit(), &SieveTextEdit::say, textToSpeechWidget, &TextEditTextToSpeech::TextToSpeechContainerWidget::say);
 #endif
+
     auto shortcut = new QShortcut(this);
     shortcut->setKey(Qt::Key_F | Qt::CTRL);
     connect(shortcut, &QShortcut::activated, mTextEditWidget, &SieveTextEditWidget::slotFind);
@@ -106,19 +109,20 @@ SieveTemplateEditDialog::~SieveTemplateEditDialog()
     disconnect(mTextEditWidget->textEdit(), &SieveTextEdit::textChanged, this, &SieveTemplateEditDialog::slotTemplateChanged);
 }
 
+void SieveTemplateEditDialog::readConfig()
+{
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveTemplateEditDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
+}
+
 void SieveTemplateEditDialog::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openStateConfig(), mySieveTemplateEditDialogGroupName);
-    group.writeEntry("Size", size());
-}
-
-void SieveTemplateEditDialog::readConfig()
-{
-    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveTemplateEditDialogGroupName);
-    const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
 
 void SieveTemplateEditDialog::slotTemplateChanged()
